@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2020 Losant IoT, Inc.
+Copyright (c) 2021 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -149,7 +149,7 @@ class Events(object):
         *  {string} filterField - Field to filter the results by. Blank or not provided means no filtering. Accepted values are: subject
         *  {string} filter - Filter to apply against the filtered field. Supports globbing. Blank or not provided means no filtering.
         *  {string} state - If provided, return events only in the given state. Accepted values are: new, acknowledged, resolved
-        *  {hash} query - Event filter JSON object which overides the filterField, filter, and state parameters. (https://api.losant.com/#/definitions/advancedEventQuery)
+        *  {hash} query - Event filter JSON object which overrides the filterField, filter, and state parameters. (https://api.losant.com/#/definitions/advancedEventQuery)
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -212,7 +212,7 @@ class Events(object):
         Parameters:
         *  {string} applicationId - ID associated with the application
         *  {string} filter - Filter to apply against event subjects. Supports globbing. Blank or not provided means no filtering.
-        *  {hash} query - Event filter JSON object which overides the filter parameter. (https://api.losant.com/#/definitions/advancedEventQuery)
+        *  {hash} query - Event filter JSON object which overrides the filter parameter. (https://api.losant.com/#/definitions/advancedEventQuery)
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -264,7 +264,7 @@ class Events(object):
         *  {string} filterField - Field to filter the events to act on by. Blank or not provided means no filtering. Accepted values are: subject
         *  {string} filter - Filter to apply against the filtered field. Supports globbing. Blank or not provided means no filtering.
         *  {string} state - If provided, act on events only in the given state. Accepted values are: new, acknowledged, resolved
-        *  {hash} query - Event filter JSON object which overides the filterField, filter, and state parameters. (https://api.losant.com/#/definitions/advancedEventQuery)
+        *  {hash} query - Event filter JSON object which overrides the filterField, filter, and state parameters. (https://api.losant.com/#/definitions/advancedEventQuery)
         *  {hash} updates - Object containing updated information for the events (https://api.losant.com/#/definitions/eventPatch)
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
