@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2020 Losant IoT, Inc.
+Copyright (c) 2021 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -349,6 +349,54 @@ class Flow(object):
 
         return self.client.request("GET", path, params=query_params, headers=headers, body=body)
 
+    def get_storage_entries_metadata(self, **kwargs):
+        """
+        Gets metadata about storage for this flow
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Organization, all.User, flow.*, or flow.getStorageEntriesMetadata.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {string} flowId - ID associated with the flow
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - The meta data for the current storage entries (https://api.losant.com/#/definitions/flowStorageMetadata)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if flow was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "flowId" in kwargs:
+            path_params["flowId"] = kwargs["flowId"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/flows/{flowId}/storage-metadata".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
     def patch(self, **kwargs):
         """
         Updates information about a flow
